@@ -378,7 +378,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return NotificationType(id=obj['id'],
                          fields=obj.get('fields', []))
 
-    def _to_monitoring_zone(self, obj, value_dict):
+    def _to_monitoring_zone(self, obj, value_dict=None):
         return MonitoringZone(id=obj['id'], label=obj['label'],
                               country_code=obj['country_code'],
                               source_ips=obj['source_ips'],
@@ -389,6 +389,11 @@ class RackspaceMonitoringDriver(MonitoringDriver):
                        'list_item_mapper': self._to_monitoring_zone}
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
+    def get_monitoring_zone(self, monitoring_zone_id):
+        url = '/monitoring_zones/%s' % (monitoring_zone_id)
+        resp = self.connection.request(url).object
+        return self._to_monitoring_zone(obj=resp)
+
     ##########
     ## Alarms
     ##########
@@ -795,6 +800,12 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
+    def ex_traceroute(self, monitoring_zone, target, target_resolver='IPv4'):
+        data = {'target': target, 'target_resolver': target_resolver}
+        path = '/monitoring_zones/%s/traceroute' % (monitoring_zone.id)
+        resp = self.connection.request(path, data=data, method='POST').object
+        return resp['result']
+
     def _to_latest_alarm_state(self, obj, value_dict):
         return LatestAlarmState(entity_id=obj['entity_id'],
                 check_id=obj['check_id'], alarm_id=obj['alarm_id'],
